##  Creating Custom Shape Templates
Users with the appropriate permission can create custom templates in the template editor by either starting from scratch and assigning custom shapes and colors to fact sheet types or modifying the existing or default templates and saving them as new.
To create a fact sheet template, do the following:
  1. Go to the Diagrams tab and select Fact Sheet Shape Templates from the left-side panel.
  2. Click + New Template to create a new template from scratch, or choose an existing one and click Edit to modify. This opens the template editor.
  3. Select and add the required shapes from the left side panel onto the canvas.
  4. Select the added shape and assign it to a fact sheet type using the Fact Sheet Type drop-down menu on the right-side panel.
  5. If the fact sheet type has subtypes, a Subtype drop-down menu will also appear. Select the subtype as needed.
  6. Adjust the color, style, and shape as needed from the format panel on the right.
  7. Repeat the steps for other shapes and fact sheet types.
  8. Click Save As at the top, enter a name for your template, and click Save.


While creating the template, if you do not assign a custom shape to a fact sheet type, the default SAP LeanIX shape will be used to represent it in the diagrams.
When you assign a shape to a fact sheet type, that shape is automatically applied to its subtypes unless you specify different shapes for them. However, assigning shapes to subtypes does not automatically apply them to the parent type if the parent type does not have a shape assigned.
You can also assign multiple shapes to the same fact sheet type. This allows users to switch between different shape variants for the fact sheet when creating a diagram.
![Creating Custom Shape Templates](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio8ccafd3f6044493f9817a49a2eb32d0f_LowRes.gif)
Creating Custom Shape Templates
